@@ -124,7 +124,6 @@ void menu_action()
     Project* project_a = xalloc(sizeof(Project));
     char message[DEFAULT_LENGTH];
 
-    d("admin\n");
     db_init();
     project_a = db_get_project(project_a);
     output_header(project_a, "メニュー", NULL, NAVI_MENU);
@@ -217,7 +216,6 @@ void env_action()
     o("\t\t\t\t</td>\n");
     o("\t\t\t</tr>\n");
     o("\t\t</table>\n");
-    o("\t\t<div class=\"description\">サーバ名、通知先アドレス、管理者アドレスが入力されていない場合、メール通知機能は機能しません。</div>\n");
     o("\t\t<input class=\"button\" type=\"submit\" value=\"更新\" />\n");
     o("\t</form>\n");
     o("</div>\n");
@@ -489,8 +487,6 @@ void update_elements()
 
         et_a = db_get_element_type(atoi(id), et_a);
 
-        d("while id: %s\n", id);
-        d("while\n");
         sprintf(name, "field%s.name", id);
         cgiFormStringNoNewlines(name, value, DEFAULT_LENGTH);
         strcpy(et_a->name, value);
@@ -525,9 +521,7 @@ void update_elements()
 
         sprintf(name, "field%s.auto_add_item", id);
         cgiFormStringNoNewlines(name, value, DEFAULT_LENGTH);
-        d("auto_add_item: %s\n", value);
         et_a->auto_add_item = atoi(value);
-        d("auto_add_item: %d\n", et_a->auto_add_item);
 
         db_update_element_type(et_a);
 
