@@ -8,16 +8,12 @@
 #define MODE_LENGTH 10
 #define DEFAULT_LENGTH 1024
 #define MAX_FILE_SIZE 512
-#define LIST_PER_PAGE 30
+#define LIST_COUNT_PER_LIST_PAGE 15
+#define LIST_COUNT_PER_SEARCH_PAGE 30
 
 typedef struct _project {
   char name[DEFAULT_LENGTH];
-  char description[DEFAULT_LENGTH];
   char home_url[DEFAULT_LENGTH];
-  char smtp_server[DEFAULT_LENGTH];
-  int smtp_port;
-  char notify_address[DEFAULT_LENGTH];
-  char admin_address[DEFAULT_LENGTH];
 } Project;
 
 
@@ -25,7 +21,6 @@ typedef struct _element {
   int element_type_id;
   char* str_val;
   int is_file;
-  int list_item_id;
   struct _element* next;
 } Element;
 
@@ -109,10 +104,15 @@ typedef struct _state {
   int count;
 } State;
 
+typedef struct _wiki {
+  int id;
+  char name[DEFAULT_LENGTH];
+  char* content;
+} Wiki;
 
 char* get_element_value_by_id(List*, int);
 char* get_element_value(List*, ElementType*);
-int get_element_lid_by_id(List*, int);
+// int get_element_lid_by_id(List*, int);
 
 
 
