@@ -90,8 +90,8 @@ void output_header(Project* project, char* title, char* script_name, int navi)
             "<head>\n"
             "\t<meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\" />\n"
             "\t<meta http-equiv=\"Content-Script-Type\" content=\"text/javascript\" />\n"
-            "\t<meta http-equiv=\"Content-Style-type\" content=\"text/css\" />\n"
-            "\t<title>%s - %s</title>\n", project->name, title);
+            "\t<meta http-equiv=\"Content-Style-type\" content=\"text/css\" />\n");
+    o(        "\t<title>"); h(project->name); o(" - %s</title>\n", title);
     o(      "\t<link rel=\"stylesheet\" type=\"text/css\" href=\"%s/../css/style.css\" />\n", cgiScriptName);
     o(      "\t<link rel=\"stylesheet\" type=\"text/css\" href=\"%s/../css/user.css\" />\n", cgiScriptName);
     if (script_name) {
@@ -147,6 +147,8 @@ void output_navigater(SearchResult* result, char* query_string)
     if (result->page > 0)
         o("<a href=\"%s/search?p=%d&amp;%s\">&lt;&lt;</a>\n", cgiScriptName, result->page - 1, query_string);
     for (i = 0; i * LIST_COUNT_PER_SEARCH_PAGE < result->hit_count; i++) {
+        if (i < result->page - 5 || i > result->page + 5)
+            continue;
         if (i == result->page)
             o("%d\n", i + 1);
         else
@@ -217,16 +219,16 @@ void output_ticket_table_header_no_link(List* element_types)
     Iterator* it;
 
     o(      "\t<tr>\n");
-    o(      "\t\t<th>ID</th>\n");
+    o(      "\t\t<th class=\"id\">ID</th>\n");
     foreach (it, element_types) {
         ElementType* et = it->element;
-        o("\t\t<th>\n");
+        o("\t\t<th class=\"field%d\">\n", et->id);
         h(et->name);
         o("\t\t</th>\n");
     }
-    o("\t\t<th>投稿日時</th>\n"
-      "\t\t<th>最終更新日時</th>\n"
-      "\t\t<th>放置日数</th>\n"
+    o("\t\t<th class=\"registerdate\">投稿日時</th>\n"
+      "\t\t<th class=\"lastregisterdate\">最終更新日時</th>\n"
+      "\t\t<th class=\"leftdate\">放置日数</th>\n"
       "\t</tr>\n");
 }
 void output_ticket_table_header(List* element_types)
@@ -237,18 +239,18 @@ void output_ticket_table_header(List* element_types)
     char* query_string = format_query_string_without_sort_and_page(query_string_buffer);
 
     o(      "\t<tr>\n");
-    o(      "\t\t<th><a href=\"%s/search?%ssort=-1&amp;%s#result\" title=\"押す度に昇順、降順で並べ替えを行ないます。\">ID</a></th>\n", cgiScriptName, reverse ? "" : "r", query_string);
+    o(      "\t\t<th class=\"id\"><a href=\"%s/search?%ssort=-1&amp;%s#result\" title=\"押す度に昇順、降順で並べ替えを行ないます。\">ID</a></th>\n", cgiScriptName, reverse ? "" : "r", query_string);
     foreach (it, element_types) {
         ElementType* et = it->element;
-        o("\t\t<th>\n");
+        o("\t\t<th class=\"field%d\">\n", et->id);
         o("\t\t\t<a href=\"%s/search?%ssort=%d&amp;%s#result\" title=\"押す度に昇順、降順で並べ替えを行ないます。\">", cgiScriptName, reverse ? "" : "r", et->id, query_string);
         h(et->name);
         o("</a>\n");
         o("\t\t</th>\n");
     }
-    o("\t\t<th><a href=\"%s/search?%ssort=-2&amp;%s#result\" title=\"押す度に昇順、降順で並べ替えを行ないます。\">投稿日時</a></th>\n", cgiScriptName, reverse ? "" : "r", query_string);
-    o("\t\t<th><a href=\"%s/search?%ssort=-3&amp;%s#result\" title=\"押す度に昇順、降順で並べ替えを行ないます。\">最終更新日時</a></th>\n", cgiScriptName, reverse ? "" : "r", query_string);
-    o("\t\t<th><a href=\"%s/search?%ssort=-3&amp;%s#result\" title=\"押す度に昇順、降順で並べ替えを行ないます。\">放置日数</a></th>\n", cgiScriptName, reverse ? "" : "r", query_string);
+    o("\t\t<th class=\"registerdate\"><a href=\"%s/search?%ssort=-2&amp;%s#result\" title=\"押す度に昇順、降順で並べ替えを行ないます。\">投稿日時</a></th>\n", cgiScriptName, reverse ? "" : "r", query_string);
+    o("\t\t<th class=\"lastregisterdate\"><a href=\"%s/search?%ssort=-3&amp;%s#result\" title=\"押す度に昇順、降順で並べ替えを行ないます。\">最終更新日時</a></th>\n", cgiScriptName, reverse ? "" : "r", query_string);
+    o("\t\t<th class=\"leftdate\"><a href=\"%s/search?%ssort=-3&amp;%s#result\" title=\"押す度に昇順、降順で並べ替えを行ないます。\">放置日数</a></th>\n", cgiScriptName, reverse ? "" : "r", query_string);
     o("\t</tr>\n");
 }
 void output_ticket_table_body(SearchResult* result, List* element_types)
@@ -314,16 +316,29 @@ void list_action()
     Project* project_a = xalloc(sizeof(Project));
     List* states_a;
     Iterator* it;
-    char message[DEFAULT_LENGTH];
     List* messages_a;
+    char** multi;
 
     db_init();
     project_a = db_get_project(project_a);
     output_header(project_a, "状態別チケット一覧", NULL, NAVI_LIST);
-    cgiFormStringNoNewlines("message", message, DEFAULT_LENGTH);
-    if (strlen(message) > 0) {
-        o("<div class=\"complete_message\">"); o(message); o("</div>\n");
+    /* メッセージの取得 */
+    if ((cgiFormStringMultiple("message", &multi)) != cgiFormNotFound) {
+        int i = 0;
+        o("<div class=\"complete_message\">");
+        while (multi[i]) {
+            if (strstr(multi[i], "[ERROR]") != NULL) {
+                o("<div class=\"error\">");
+            } else {
+                o("<div>");
+            }
+            h(multi[i]);
+            o("</div>");
+            i++;
+        }
+        o("</div>\n");
     }
+    cgiStringArrayFree(multi);
     list_alloc(element_types_a, ElementType);
     element_types_a = db_get_element_types_4_list(element_types_a);
     o("<h2>"); h(project_a->name); o(" - 状態別チケット一覧</h2>\n");
@@ -389,7 +404,7 @@ void list_action()
                     cgiScriptName,
                     ELEM_ID_STATUS);
             u(s->name);
-            o("\">状態が%sである全てのチケットを表示する</a></div>\n", s->name);
+            o("\">状態が"); h(s->name); o("である全てのチケットを表示する</a></div>\n");
         }
         output_ticket_table_status_index(result_a, element_types_a);
         if (result_a->hit_count == LIST_COUNT_PER_LIST_PAGE) {
@@ -397,7 +412,7 @@ void list_action()
                     cgiScriptName,
                     ELEM_ID_STATUS);
             u(s->name);
-            o("\">状態が%sである全てのチケットを表示する</a></div>\n", s->name);
+            o("\">状態が"); h(s->name); o("である全てのチケットを表示する</a></div>\n");
         }
         list_free(result_a->messages);
         xfree(result_a);
@@ -667,17 +682,13 @@ void output_ticket_information_4_csv_report_header(List* element_types)
 {
     Iterator* it;
 
-    d("zz\n");
     csv_field("ID"); 
-    d("zz11\n");
     o(",");
-    d("zz\n");
     foreach (it, element_types) {
         ElementType* et = it->element;
         if (!et->ticket_property) continue;
         csv_field(et->name); o(",");
     }
-    d("zz\n");
     csv_field("投稿日時"); o(",");
     csv_field("最終更新日時"); o(",");
     csv_field("放置日数"); o("\r\n");
@@ -1110,7 +1121,6 @@ void ticket_action()
                 if (et->type == ELEM_TYPE_UPLOADFILE) {
                     if (strlen(value)) {
                         char* id_str = get_element_value_by_id(elements_a, ELEM_ID_ID);
-                        d("id_str: %s\n", id_str);
                         o("<a href=\"%s/download/%d/", 
                                 cgiScriptName, 
                                 db_get_element_file_id(atoi(id_str), et->id)); 
@@ -1173,6 +1183,9 @@ void ticket_action()
             /* チケット属性で、直前の値と同じ項目は表示しない。 */
             if (et->ticket_property == 1 && strcmp(value, last_value) == 0)
                 continue;
+            /* チケット属性でなくて、空白の項目は表示しない。 */
+            if (et->ticket_property == 0 && strlen(value) == 0)
+                continue;
             o(      "\t<tr>\n"
                     "\t\t<th>");
             h(et->name);
@@ -1185,10 +1198,18 @@ void ticket_action()
                 default:
                     if (et->type == ELEM_TYPE_UPLOADFILE) {
                         if (strlen(value)) {
-                            o("<a href=\"%s/download/%d/", 
-                                    cgiScriptName, 
-                                    db_get_element_file_id(message_ids_a[i], et->id)); 
+                            char buf[DEFAULT_LENGTH];
+                            char* mime_type;
+                            int file_id = db_get_element_file_id(message_ids_a[i], et->id);
+                            o("<a href=\"%s/download/%d/", cgiScriptName, file_id); 
                             u(value); o("\" target=\"_blank\">");h(value); o("</a>\n");
+                            mime_type = db_get_element_file_mime_type(message_ids_a[i], et->id, buf);
+                            if (strstr(mime_type, "image") != NULL) {
+                                o("<div>\n");
+                                o("<img class=\"attachment_image\" src=\"%s/download/%d\" alt=\"attachment file\" />\n",
+                                        cgiScriptName, file_id);
+                                o("</div>\n");
+                            }
                         }
                     } else {
                         hm(value);
@@ -1269,17 +1290,15 @@ void register_submit_action()
     Project* project_a = xalloc(sizeof(Project));
     List* element_types_a;
     Iterator* it;
-    Iterator* it_hook;
     List* elements_a = NULL;
     Message* ticket_a;
     char ticket_id[DEFAULT_LENGTH];
     int mode = get_mode();
-/*     int mail_result; */
     char** multi;
     char save2cookie[2];
-    char* complete_message_a = NULL;
+    char* complete_message = NULL;
+    HOOK* hook = NULL;
 
-    d("start\n");
     cgiFormStringNoNewlines("save2cookie", save2cookie, 2);
     if (mode == MODE_INVALID)
         die("reqired invalid mode.");
@@ -1296,7 +1315,6 @@ void register_submit_action()
     list_alloc(elements_a, Element);
     if (mode == MODE_REGISTER || mode == MODE_REPLY) {
         char* value_a = xalloc(sizeof(char) * VALUE_LENGTH); /* 1M */
-        HOOK* hook;
         /* register, reply */
         foreach (it, element_types_a) {
             ElementType* et = it->element;
@@ -1397,17 +1415,10 @@ void register_submit_action()
         /* hook */
         hook = init_hook(HOOK_MODE_REGISTERED);
         hook = exec_hook(hook, project_a, ticket_a, elements_a, element_types_a);
-        complete_message_a = xalloc(sizeof(char) * (get_hook_message_size(hook) + 32));
         if (mode == MODE_REGISTER)
-            strcpy(complete_message_a, "登録しました。");
+            complete_message = "登録しました。";
         else if (mode == MODE_REPLY)
-            strcpy(complete_message_a, "返信しました。");
-        foreach (it_hook, hook->results) {
-            HOOK_RESULT* result = it_hook->element;
-            d("hook_message: %s\n", result->message);
-            strcat(complete_message_a, result->message);
-        }
-        clean_hook(hook);
+            complete_message = "返信しました。";
         xfree(project_a);
         list_free(element_types_a);
         free_element_list(elements_a);
@@ -1415,8 +1426,8 @@ void register_submit_action()
     }
     db_finish();
 
-    redirect("/list", complete_message_a);
-    if (complete_message_a) xfree(complete_message_a);
+    redirect_with_hook_messages("/list", complete_message, hook->results);
+    if (hook) clean_hook(hook);
     return;
 
 file_size_error:
@@ -1638,7 +1649,7 @@ got_item:
                 foreach (it_item, items_a) {
                     State* s = it_item->element;
                     int count = s == NULL ? 0 : s->count;
-                    o("\t\t[\"%s\t(%d)\", %d]", s->name, count, count);
+                    o("\t\t[\""); h(s->name); o("\t(%d)\", %d]", count, count);
                     if (iterator_next(it_item)) o(",");
                     o("\n");
                 }
@@ -1698,6 +1709,7 @@ void edit_top_action()
             "<li>行頭に****を記述した行は、極小見出しになります。</li>\n"
             "<li>行頭に-を記述した行は、箇条書きになります。</li>\n"
             "<li>行頭に----を記述した行は、区切り線になります。</li>\n"
+            "<li>行頭が空白スペースから始まる行は、整形済みブロックになります。</li>\n"
             "</ul>\n"
             "</div>\n"
             "</div>\n");
